import { Immutable } from "immer";
import { FunctionComponent } from "react";
import { IActions, IActionsObj, IAsyncActions, IAsyncActionsObj, IHooks, IHooksObj, IUseProduce, IUseStore } from "./common";
import { IPersistenceOptions } from "./plugins/persistenceStorage";
/**
 * Create React Context version of a **react-state-selector** global store
 */
export declare function createStoreContext<TStore, THooks extends IHooks<TStore>, TActions extends IActions<TStore>, TAsyncActions extends IAsyncActions<TStore>>(initialStore: Immutable<TStore>, options?: {
    /**
     * Custom hooks.
     */
    hooks?: THooks;
    /**
     * Custom actions.
     */
    actions?: TActions;
    /**
     * Custom async actions.
     */
    asyncActions?: TAsyncActions;
    /**
     * Name used to activate Redux DevTools.
     */
    devName?: string;
    /**
     * Flag to manually activate the usage of the Redux DevTools in production.
     */
    devToolsInProduction?: boolean;
    /**
     * Storage persistence options for the store.
     * By default uses window.localStorage
     */
    storagePersistence?: IPersistenceOptions;
}): {
    /**
     * React Context Provider of an instance of the global store
     */
    Provider: FunctionComponent<{
        debugName?: string;
    }>;
    /**
     * Default hook that listens for any change in the store.
     */
    useStore: IUseStore<TStore>;
    /**
     * Default hook that contains "produce" direct function to mutate the store and "asyncProduce" async version of produce
     */
    useProduce: IUseProduce<TStore>;
    /**
     * Hook that contains the custom actions specified in the options
     */
    useActions: () => IActionsObj<TStore, typeof options>;
    /**
     * Hook that contains the custom async actions specified in the options
     */
    useAsyncActions: () => IAsyncActionsObj<TStore, typeof options>;
    /**
     * Object containing the custom hooks specified in the options
     */
    hooks: IHooksObj<TStore, typeof options>;
    /**
     * Returns promise that resolves when the store is ready to be used.
     * Only useful when using an Async Storage Persistance, like AsyncStorage from React Native
     */
    useIsReady: () => boolean;
};
